==> piwik-1.12.tgz: piwik/core/DataFiles/Currencies.php <==
<?php
/**
 * Piwik - Open source web analytics
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 * @category Piwik
 * @package DataFiles
 */

/**
 * International currencies in circulation
 *
 * @see http://en.wikipedia.org/wiki/List_of_circulating_currencies
 * @see http://www.iso.org/iso/currency_codes_list-1.html
 */
if (!isset($GLOBALS['Piwik_CurrencyList'])) {
    $GLOBALS['Piwik_CurrencyList'] = array(
        // 'ISO-4217 CODE' => array('currency symbol', 'description'),

        // Top 5 by global trading volume
        'USD' => array('$', 'US dollar'),
        'EUR' => array('€', 'Euro'),
        'JPY' => array('¥', 'Japanese yen'),
        'GBP' => array('£', 'British pound'),
        'CHF' => array('Fr', 'Swiss franc'),

        'AFN' => array('؋', 'Afghan afghani'),
        'ALL' => array('L', 'Albanian lek'),
        'DZD' => array('د.ج', 'Algerian dinar'),
        'AOA' => array('Kz', 'Angolan kwanza'),
        'ARS' => array('$', 'Argentine peso'),
        'AMD' => array('դր.', 'Armenian dram'),
        'AWG' => array('ƒ', 'Aruban florin'),
        'AUD' => array('$', 'Australian dollar'),
        'AZN' => array('m', 'Azerbaijani manat'),
        'BSD' => array('$', 'Bahamian dollar'),
        'BHD' => array('.د.ب', 'Bahraini dinar'),
        'BDT' => array('৳', 'Bangladeshi taka'),
        'BBD' => array('$', 'Barbadian dollar'),
        'BYR' => array('Br', 'Belarusian ruble'),
        'BZD' => array('$', 'Belize dollar'),
        'BMD' => array('$', 'Bermudian dollar'),
        'BTC' => array('BTC', 'Bitcoin'),
        'BTN' => array('Nu.', 'Bhutanese ngultrum'),
        'BOB' => array('Bs.', 'Bolivian boliviano'),
        'BAM' => array('KM', 'Bosnia Herzegovina mark'),
        'BWP' => array('P', 'Botswana pula'),
        'BRL' => array('R$', 'Brazilian real'),
//			'GBP' => array('£', 'British pound'),
        'BND' => array('$', 'Brunei dollar'),
        'BGN' => array('лв', 'Bulgarian lev'),
        'BIF' => array('Fr', 'Burundian franc'),
        'KHR' => array('៛', 'Cambodian riel'),
        'CAD' => array('$', 'Canadian dollar'),
        'CVE' => array('$', 'Cape Verdean escudo'),
        'KYD' => array('$', 'Cayman Islands dollar'),
        'XAF' => array('Fr', 'Central African CFA franc'),
        'CLP' => array('$', 'Chilean peso'),
        'CNY' => array('元', 'Chinese yuan'),
        'COP' => array('$', 'Colombian peso'),
        'KMF' => array('Fr', 'Comorian franc'),
        'CDF' => array('Fr', 'Congolese franc'),
        'CRC' => array('₡', 'Costa Rican colón'),
        'HRK' => array('kn', 'Croatian kuna'),
        'XPF' => array('F', 'CFP franc'),
        'CUC' => array('$', 'Cuban convertible peso'),
        'CUP' => array('$', 'Cuban peso'),
        'CMG' => array('ƒ', 'Curaçao and Sint Maarten guilder'),
        'CZK' => array('Kč', 'Czech koruna'),
        'DKK' => array('kr', 'Danish krone'),
        'DJF' => array('Fr', 'Djiboutian franc'),
        'DOP' => array('$', 'Dominican peso'),
        'XCD' => array('$', 'East Caribbean dollar'),
        'EGP' => array('ج.م', 'Egyptian pound'),
        'ERN' => array('Nfk', 'Eritrean nakfa'),
        'EEK' => array('kr', 'Estonian kroon'),
        'ETB' => array('Br', 'Ethiopian birr'),
//			'EUR' => array('€', 'Euro'),
        'FKP' => array('£', 'Falkland Islands pound'),
        'FJD' => array('$', 'Fijian dollar'),
        'GMD' => array('D', 'Gambian dalasi'),
        'GEL' => array('ლ', 'Georgian lari'),
        'GHS' => array('₵', 'Ghanaian cedi'),
        'GIP' => array('£', 'Gibraltar pound'),
        'GTQ' => array('Q', 'Guatemalan quetzal'),
        'GNF' => array('Fr', 'Guinean franc'),
        'GYD' => array('$', 'Guyanese dollar'),
        'HTG' => array('G', 'Haitian gourde'),
        'HNL' => array('L', 'Honduran lempira'),
        'HKD' => array('$', 'Hong Kong dollar'),
        'HUF' => array('Ft', 'Hungarian forint'),
        'ISK' => array('kr', 'Icelandic króna'),
        'INR' => array('‎₹', 'Indian rupee'),
        'IDR' => array('Rp', 'Indonesian rupiah'),
        'IRR' => array('﷼', 'Iranian rial'),
        'IQD' => array('ع.د', 'Iraqi dinar'),
        'ILS' => array('₪', 'Israeli new shekel'),
        'JMD' => array('$', 'Jamaican dollar'),
//			'JPY' => array('¥', 'Japanese yen'),
        'JOD' => array('د.ا', 'Jordanian dinar'),
        'KZT' => array('₸', 'Kazakhstani tenge'),
        'KES' => array('Sh', 'Kenyan shilling'),
        'KWD' => array('د.ك', 'Kuwaiti dinar'),
        'KGS' => array('лв', 'Kyrgyzstani som'),
        'LAK' => array('₭', 'Lao kip'),
        'LVL' => array('Ls', 'Latvian lats'),
        'LBP' => array('ل.ل', 'Lebanese pound'),
        'LSL' => array('L', 'Lesotho loti'),
        'LRD' => array('$', 'Liberian dollar'),
        'LYD' => array('ل.د', 'Libyan dinar'),
        'LTL' => array('Lt', 'Lithuanian litas'),
        'MOP' => array('P', 'Macanese pataca'),
        'MKD' => array('ден', 'Macedonian denar'),
        'MGA' => array('Ar', 'Malagasy ariary'),
        'MWK' => array('MK', 'Malawian kwacha'),
        'MYR' => array('RM', 'Malaysian ringgit'),
        'MVR' => array('ރ.', 'Maldivian rufiyaa'),
        'MRO' => array('UM', 'Mauritanian ouguiya'),
        'MUR' => array('₨', 'Mauritian rupee'),
        'MXN' => array('$', 'Mexican peso'),
        'MDL' => array('L', 'Moldovan leu'),
        'MNT' => array('₮', 'Mongolian tögrög'),
        'MAD' => array('د.م.', 'Moroccan dirham'),
        'MZN' => array('MTn', 'Mozambican metical'),
        'MMK' => array('K', 'Myanma kyat'),
        'NAD' => array('$', 'Namibian dollar'),
        'NPR' => array('₨', 'Nepalese rupee'),
        'ANG' => array('ƒ', 'Netherlands Antillean guilder'),
        'TWD' => array('$', 'New Taiwan dollar'),
        'NZD' => array('$', 'New Zealand dollar'),
        'NIO' => array('C$', 'Nicaraguan córdoba'),
        'NGN' => array('₦', 'Nigerian naira'),
        'KPW' => array('₩', 'North Korean won'),
        'NOK' => array('kr', 'Norwegian krone'),
        'OMR' => array('ر.ع.', 'Omani rial'),
        'PKR' => array('₨', 'Pakistani rupee'),
        'PAB' => array('B/.', 'Panamanian balboa'),
        'PGK' => array('K', 'Papua New Guinean kina'),
        'PYG' => array('₲', 'Paraguayan guaraní'),
        'PEN' => array('S/.', 'Peruvian nuevo sol'),
        'PHP' => array('₱', 'Philippine peso'),
        'PLN' => array('zł', 'Polish złoty'),
        'QAR' => array('ر.ق', 'Qatari riyal'),
        'RON' => array('L', 'Romanian leu'),
        'RUB' => array('руб.', 'Russian ruble'),
        'RWF' => array('Fr', 'Rwandan franc'),
        'SHP' => array('£', 'Saint Helena pound'),
        'SVC' => array('₡', 'Salvadoran colón'),
        'WST' => array('T', 'Samoan tala'),
        'STD' => array('Db', 'São Tomé and Príncipe dobra'),
        'SAR' => array('ر.س', 'Saudi riyal'),
        'RSD' => array('дин. or din.', 'Serbian dinar'),
        'SCR' => array('₨', 'Seychellois rupee'),
        'SLL' => array('Le', 'Sierra Leonean leone'),
        'SGD' => array('$', 'Singapore dollar'),
        'SBD' => array('$', 'Solomon Islands dollar'),
        'SOS' => array('Sh', 'Somali shilling'),
        'ZAR' => array('R', 'South African rand'),
        'KRW' => array('₩', 'South Korean won'),
        'LKR' => array('Rs', 'Sri Lankan rupee'),
        'SDG' => array('جنيه سوداني', 'Sudanese pound'),
        'SRD' => array('$', 'Surinamese dollar'),
        'SZL' => array('L', 'Swazi lilangeni'),
        'SEK' => array('kr', 'Swedish krona'),
//			'CHF' => array('Fr', 'Swiss franc'),
        'SYP' => array('ل.س', 'Syrian pound'),
        'TJS' => array('ЅМ', 'Tajikistani somoni'),
        'TZS' => array('Sh', 'Tanzanian shilling'),
        'THB' => array('฿', 'Thai baht'),
        'TOP' => array('T$', 'Tongan paʻanga'),
        'TTD' => array('$', 'Trinidad and Tobago dollar'),
        'TND' => array('د.ت', 'Tunisian dinar'),
        'TRY' => array('TL', 'Turkish lira'),
        'TMM' => array('m', 'Turkmenistani manat'),
        'UGX' => array('Sh', 'Ugandan shilling'),
        'UAH' => array('₴', 'Ukrainian hryvnia'),
        'AED' => array('د.إ', 'United Arab Emirates dirham'),
//			'USD' => array('$', 'United States dollar'),
        'UYU' => array('$', 'Uruguayan peso'),
        'UZS' => array('лв', 'Uzbekistani som'),
        'VUV' => array('Vt', 'Vanuatu vatu'),
        'VEF' => array('Bs F', 'Venezuelan bolívar'),
        'VND' => array('₫', 'Vietnamese đồng'),
        'XOF' => array('Fr', 'West African CFA franc'),
        'YER' => array('﷼', 'Yemeni rial'),
        'ZMK' => array('ZK', 'Zambian kwacha'),
        'ZWL' => array('$', 'Zimbabwean dollar'),
    );
}

==> piwik-2.0.3.tgz: piwik/core/DataFiles/Currencies.php <==
<?php
/**
 * Piwik - Open source web analytics
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 * @category Piwik
 * @package DataFiles
 */

/**
 * International currencies in circulation
 *
 * @see http://en.wikipedia.org/wiki/List_of_circulating_currencies
 * @see http://www.iso.org/iso/currency_codes_list-1.html
 */
if (!isset($GLOBALS['Piwik_CurrencyList'])) {
    $GLOBALS['Piwik_CurrencyList'] = array(
        // 'ISO-4217 CODE' => array('currency symbol', 'description'),

        // Top 5 by global trading volume
        'USD' => array('$', 'US dollar'),
        'EUR' => array('€', 'Euro'),
        'JPY' => array('¥', 'Japanese yen'),
        'GBP' => array('£', 'British pound'),
        'CHF' => array('Fr', 'Swiss franc'),

        'AFN' => array('؋', 'Afghan afghani'),
        'ALL' => array('L', 'Albanian lek'),
        'DZD' => array('د.ج', 'Algerian dinar'),
        'AOA' => array('Kz', 'Angolan kwanza'),
        'ARS' => array('$', 'Argentine peso'),
        'AMD' => array('դր.', 'Armenian dram'),
        'AWG' => array('ƒ', 'Aruban florin'),
        'AUD' => array('$', 'Australian dollar'),
        'AZN' => array('m', 'Azerbaijani manat'),
        'BSD' => array('$', 'Bahamian dollar'),
        'BHD' => array('.د.ب', 'Bahraini dinar'),
        'BDT' => array('৳', 'Bangladeshi taka'),
        'BBD' => array('$', 'Barbadian dollar'),
        'BYR' => array('Br', 'Belarusian ruble'),
        'BZD' => array('$', 'Belize dollar'),
        'BMD' => array('$', 'Bermudian dollar'),
        'BTC' => array('BTC', 'Bitcoin'),
        'BTN' => array('Nu.', 'Bhutanese ngultrum'),
        'BOB' => array('Bs.', 'Bolivian boliviano'),
        'BAM' => array('KM', 'Bosnia Herzegovina mark'),
        'BWP' => array('P', 'Botswana pula'),
        'BRL' => array('R$', 'Brazilian real'),
//			'GBP' => array('£', 'British pound'),
        'BND' => array('$', 'Brunei dollar'),
        'BGN' => array('лв', 'Bulgarian lev'),
        'BIF' => array('Fr', 'Burundian franc'),
        'KHR' => array('៛', 'Cambodian riel'),
        'CAD' => array('$', 'Canadian dollar'),
        'CVE' => array('$', 'Cape Verdean escudo'),
        'KYD' => array('$', 'Cayman Islands dollar'),
        'XAF' => array('Fr', 'Central African CFA franc'),
        'CLP' => array('$', 'Chilean peso'),
        'CNY' => array('元', 'Chinese yuan'),
        'COP' => array('$', 'Colombian peso'),
        'KMF' => array('Fr', 'Comorian franc'),
        'CDF' => array('Fr', 'Congolese franc'),
        'CRC' => array('₡', 'Costa Rican colón'),
        'HRK' => array('kn', 'Croatian kuna'),
        'XPF' => array('F', 'CFP franc'),
        'CUC' => array('$', 'Cuban convertible peso'),
        'CUP' => array('$', 'Cuban peso'),
        'CMG' => array('ƒ', 'Curaçao and Sint Maarten guilder'),
        'CZK' => array('Kč', 'Czech koruna'),
        'DKK' => array('kr', 'Danish krone'),
        'DJF' => array('Fr', 'Djiboutian franc'),
        'DOP' => array('$', 'Dominican peso'),
        'XCD' => array('$', 'East Caribbean dollar'),
        'EGP' => array('ج.م', 'Egyptian pound'),
        'ERN' => array('Nfk', 'Eritrean nakfa'),
        'EEK' => array('kr', 'Estonian kroon'),
        'ETB' => array('Br', 'Ethiopian birr'),
//			'EUR' => array('€', 'Euro'),
        'FKP' => array('£', 'Falkland Islands pound'),
        'FJD' => array('$', 'Fijian dollar'),
        'GMD' => array('D', 'Gambian dalasi'),
        'GEL' => array('ლ', 'Georgian lari'),
        'GHS' => array('₵', 'Ghanaian cedi'),
        'GIP' => array('£', 'Gibraltar pound'),
        'GTQ' => array('Q', 'Guatemalan quetzal'),
        'GNF' => array('Fr', 'Guinean franc'),
        'GYD' => array('$', 'Guyanese dollar'),
        'HTG' => array('G', 'Haitian gourde'),
        'HNL' => array('L', 'Honduran lempira'),
        'HKD' => array('$', 'Hong Kong dollar'),
        'HUF' => array('Ft', 'Hungarian forint'),
        'ISK' => array('kr', 'Icelandic króna'),
        'INR' => array('‎₹', 'Indian rupee'),
        'IDR' => array('Rp', 'Indonesian rupiah'),
        'IRR' => array('﷼', 'Iranian rial'),
        'IQD' => array('ع.د', 'Iraqi dinar'),
        'ILS' => array('₪', 'Israeli new shekel'),
        'JMD' => array('$', 'Jamaican dollar'),
//			'JPY' => array('¥', 'Japanese yen'),
        'JOD' => array('د.ا', 'Jordanian dinar'),
        'KZT' => array('₸', 'Kazakhstani tenge'),
        'KES' => array('Sh', 'Kenyan shilling'),
        'KWD' => array('د.ك', 'Kuwaiti dinar'),
        'KGS' => array('лв', 'Kyrgyzstani som'),
        'LAK' => array('₭', 'Lao kip'),
        'LVL' => array('Ls', 'Latvian lats'),
        'LBP' => array('ل.ل', 'Lebanese pound'),
        'LSL' => array('L', 'Lesotho loti'),
        'LRD' => array('$', 'Liberian dollar'),
        'LYD' => array('ل.د', 'Libyan dinar'),
        'LTL' => array('Lt', 'Lithuanian litas'),
        'MOP' => array('P', 'Macanese pataca'),
        'MKD' => array('ден', 'Macedonian denar'),
        'MGA' => array('Ar', 'Malagasy ariary'),
        'MWK' => array('MK', 'Malawian kwacha'),
        'MYR' => array('RM', 'Malaysian ringgit'),
        'MVR' => array('ރ.', 'Maldivian rufiyaa'),
        'MRO' => array('UM', 'Mauritanian ouguiya'),
        'MUR' => array('₨', 'Mauritian rupee'),
        'MXN' => array('$', 'Mexican peso'),
        'MDL' => array('L', 'Moldovan leu'),
        'MNT' => array('₮', 'Mongolian tögrög'),
        'MAD' => array('د.م.', 'Moroccan dirham'),
        'MZN' => array('MTn', 'Mozambican metical'),
        'MMK' => array('K', 'Myanma kyat'),
        'NAD' => array('$', 'Namibian dollar'),
        'NPR' => array('₨', 'Nepalese rupee'),
        'ANG' => array('ƒ', 'Netherlands Antillean guilder'),
        'TWD' => array('$', 'New Taiwan dollar'),
        'NZD' => array('$', 'New Zealand dollar'),
        'NIO' => array('C$', 'Nicaraguan córdoba'),
        'NGN' => array('₦', 'Nigerian naira'),
        'KPW' => array('₩', 'North Korean won'),
        'NOK' => array('kr', 'Norwegian krone'),
        'OMR' => array('ر.ع.', 'Omani rial'),
        'PKR' => array('₨', 'Pakistani rupee'),
        'PAB' => array('B/.', 'Panamanian balboa'),
        'PGK' => array('K', 'Papua New Guinean kina'),
        'PYG' => array('₲', 'Paraguayan guaraní'),
        'PEN' => array('S/.', 'Peruvian nuevo sol'),
        'PHP' => array('₱', 'Philippine peso'),
        'PLN' => array('zł', 'Polish złoty'),
        'QAR' => array('ر.ق', 'Qatari riyal'),
        'RON' => array('L', 'Romanian leu'),
        'RUB' => array('руб.', 'Russian ruble'),
        'RWF' => array('Fr', 'Rwandan franc'),
        'SHP' => array('£', 'Saint Helena pound'),
        'SVC' => array('₡', 'Salvadoran colón'),
        'WST' => array('T', 'Samoan tala'),
        'STD' => array('Db', 'São Tomé and Príncipe dobra'),
        'SAR' => array('ر.س', 'Saudi riyal'),
        'RSD' => array('дин. or din.', 'Serbian dinar'),
        'SCR' => array('₨', 'Seychellois rupee'),
        'SLL' => array('Le', 'Sierra Leonean leone'),
        'SGD' => array('$', 'Singapore dollar'),
        'SBD' => array('$', 'Solomon Islands dollar'),
        'SOS' => array('Sh', 'Somali shilling'),
        'ZAR' => array('R', 'South African rand'),
        'KRW' => array('₩', 'South Korean won'),
        'LKR' => array('Rs', 'Sri Lankan rupee'),
        'SDG' => array('جنيه سوداني', 'Sudanese pound'),
        'SRD' => array('$', 'Surinamese dollar'),
        'SZL' => array('L', 'Swazi lilangeni'),
        'SEK' => array('kr', 'Swedish krona'),
//			'CHF' => array('Fr', 'Swiss franc'),
        'SYP' => array('ل.س', 'Syrian pound'),
        'TJS' => array('ЅМ', 'Tajikistani somoni'),
        'TZS' => array('Sh', 'Tanzanian shilling'),
        'THB' => array('฿', 'Thai baht'),
        'TOP' => array('T$', 'Tongan paʻanga'),
        'TTD' => array('$', 'Trinidad and Tobago dollar'),
        'TND' => array('د.ت', 'Tunisian dinar'),
        'TRY' => array('TL', 'Turkish lira'),
        'TMM' => array('m', 'Turkmenistani manat'),
        'UGX' => array('Sh', 'Ugandan shilling'),
        'UAH' => array('₴', 'Ukrainian hryvnia'),
        'AED' => array('د.إ', 'United Arab Emirates dirham'),
//			'USD' => array('$', 'United States dollar'),
        'UYU' => array('$', 'Uruguayan peso'),
        'UZS' => array('лв', 'Uzbekistani som'),
        'VUV' => array('Vt', 'Vanuatu vatu'),
        'VEF' => array('Bs F', 'Venezuelan bolívar'),
        'VND' => array('₫', 'Vietnamese đồng'),
        'XOF' => array('Fr', 'West African CFA franc'),
        'YER' => array('﷼', 'Yemeni rial'),
        'ZMW' => array('ZK', 'Zambian kwacha'),
        'ZWL' => array('$', 'Zimbabwean dollar'),
    );
}
